@@ -1,15 +1,15 @@
 import asyncio
+import logging
 import random
 import time
-import logging
 from uuid import uuid4
 
 from Bubot.Helpers.ExtException import ExtException
+
 from BubotObj.OcfDevice.subtype.Device.DeviceCore import DeviceCore
 
 
 class MainLoopMixin(DeviceCore):
-    # _logger = logging.getLogger(__name__)
 
     def run(self):
         try:
@@ -39,7 +39,7 @@ class MainLoopMixin(DeviceCore):
             if not di:
                 di = str(uuid4())
                 self.set_device_id(di)
-            self.log = logging.getLogger('{0}:{1}'.format(self.__class__.__name__, di[-5:]))
+            self.log = self.get_logger(di)
             self.log.setLevel(getattr(logging, self.get_param('/oic/con', 'logLevel', 'error').upper()))
             self.save_config()
 
@@ -82,17 +82,17 @@ class MainLoopMixin(DeviceCore):
             self.log.info("end main")
 
     async def on_pending(self):
-        self.log.info("on_pending")
+        self.log.info("")
         self.set_param('/oic/mnt', 'currentMachineState', 'idle', save_config=True)
 
     async def on_idle(self):
         pass
 
     async def on_cancelled(self):
-        self.log.info("on_cancelled")
+        self.log.info("")
         self.set_param('/oic/mnt', 'currentMachineState', '')
         raise asyncio.CancelledError()
 
     async def on_stopped(self):
-        self.log.info("on_stopped")
+        self.log.info("")
         self.set_param('/oic/mnt', 'currentMachineState', 'cancelled')
